pub struct ClientProviderProxy { /* private fields */ }Implementations
Sourceimpl ClientProviderProxy
impl ClientProviderProxy
Sourcepub fn take_event_stream(&self) -> ClientProviderEventStream
pub fn take_event_stream(&self) -> ClientProviderEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn new_client(
&self,
interface_id: u64,
params: &NewClientParams,
request: ServerEnd<ClientMarker>,
) -> Result<(), Error>
pub fn new_client( &self, interface_id: u64, params: &NewClientParams, request: ServerEnd<ClientMarker>, ) -> Result<(), Error>
Provides a DHCPv4 client.
- request
paramsthe parameters to create the client with. - request
requestgrants control over the client.
Sourcepub fn check_presence(&self) -> QueryResponseFut<(), FDomainResourceDialect>
pub fn check_presence(&self) -> QueryResponseFut<(), FDomainResourceDialect>
No-op method that allows checking for presence.
TODO(https://fxbug.dev/296283299): It’s not currently possible for a client with an optionally-provided protocol to check whether there’s someone on the other end without making a FIDL call . This method provides a workaround by giving a client a method that it can call to check for liveness.
TODO(https://fxbug.dev/42076541): Remove this once the DHCP out-of-stack client is always being used.